=========
Cantal-Py
=========

:Status: Beta
:Documentation: https://cantal-py.readthedocs.io/
:Parent Project: https://github.com/tailhook/cantal

Cantal is an expermimental heartbeating, monitoring and statistics solution.
This is a python library for sending statistics data to cantal.

